**Example 1: 导出木马记录**

导出木马记录

Input: 

```
tccli cwp ExportMalwares --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "RequestId": "354f4ac3-8546-4516-8c8a-69e3ab73aa8a",
        "DownloadUrl": "",
        "TaskId": "123"
    }
}
```

